"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.creator = exports.messages = void 0;
const path_1 = __importDefault(require("path"));
const js_yaml_1 = require("js-yaml");
exports.messages = {
    disallowToUseKindSecret: {
        en: (props) => `disallow to use Kind: Secret in manifest: ${props.FILE_NAME}`,
        ja: (props) => `Kind: Secretのmanifestがみつかりました: ${props.FILE_NAME}`,
    },
};
function reportIfFoundKindSecret({ source, context, t, }) {
    try {
        // Support multi manifest
        const manifestObjects = js_yaml_1.safeLoadAll(source.content);
        manifestObjects.forEach((manifestObject) => {
            // Kind: Secret
            if (manifestObject["Kind"] !== "Secret") {
                return;
            }
            context.report({
                message: t("disallowToUseKindSecret", {
                    FILE_NAME: source.filePath ? path_1.default.basename(source.filePath) : "",
                }),
                range: [0, source.content.length],
            });
        });
    }
    catch (_a) {
        // nope
    }
}
exports.creator = {
    messages: exports.messages,
    meta: {
        id: "@secretlint/secretlint-rule-no-k8s-kind-secret",
        recommended: false,
        type: "scanner",
        supportedContentTypes: ["text"],
        docs: {
            url: "https://github.com/secretlint/secretlint/blob/master/packages/%40secretlint/secretlint-rule-no-k8s-kind-secret/README.md",
        },
    },
    create(context, options) {
        const t = context.createTranslator(exports.messages);
        return {
            file(source) {
                if (source.ext === ".yaml" || source.ext === ".yml") {
                    reportIfFoundKindSecret({ source, options, context, t });
                }
            },
        };
    },
};
exports.default = exports.creator;
//# sourceMappingURL=index.js.map